use sea_query::{tests_cfg::*, *};

mod foreign_key;
mod index;
#[allow(deprecated)]
mod query;
mod table;
mod types;
